==> headjack-0.8.4.tar.gz: headjack-0.8.4/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/headjack/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.rst') as f:
        return f.read()

install_requires = [
    'pyyaml',
    'headjack',
    'fundamentals',
    'pypolyglot',
    'markdown',
    'pyperclip',
    'picaxe'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    c_exclude_list = ['healpy', 'astropy',
                      'numpy', 'sherlock', 'wcsaxes', 'HMpTy', 'ligo-gracedb']
    for e in c_exclude_list:
        try:
            install_requires.remove(e)
        except:
            pass

setup(name="headjack",
      version=__version__,
      description="Tools to download, organize, share, archive and reference various kinds of media. Books, podcasts, articles, videos ...",
      long_description=readme(),
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.7',
          'Topic :: Utilities',
      ],
      keywords=['media, download, database, tools'],
      url='https://github.com/thespacedoctor/headjack',
      download_url='https://github.com/thespacedoctor/headjack/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['headjack=headjack.cl_utils:main'],
      },
      zip_safe=False)

==> headjack-0.8.6.tar.gz: headjack-0.8.6/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/headjack/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.rst') as f:
        return f.read()

install_requires = [
    'pyyaml',
    'headjack',
    'fundamentals',
    'pypolyglot',
    'markdown',
    'pyperclip',
    'picaxe'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    c_exclude_list = ['healpy', 'astropy',
                      'numpy', 'sherlock', 'wcsaxes', 'HMpTy', 'ligo-gracedb']
    for e in c_exclude_list:
        try:
            install_requires.remove(e)
        except:
            pass

setup(name="headjack",
      version=__version__,
      description="Tools to download, organize, share, archive and reference various kinds of media. Books, podcasts, articles, videos ...",
      long_description=readme(),
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.7',
          'Topic :: Utilities',
      ],
      keywords=['media, download, database, tools'],
      url='https://github.com/thespacedoctor/headjack',
      download_url='https://github.com/thespacedoctor/headjack/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['headjack=headjack.cl_utils:main',
                              'papers=headjack.archiver.papers:main'],
      },
      zip_safe=False)
